@@ -3,18 +3,18 @@
 void Store::define(std::string const &symbol, bool isFunction)
 {
     auto iter = find_if(
-                    d_xrefData.begin(), d_xrefData.end(),
+                    d_xrefVector.begin(), d_xrefVector.end(),
                     [&](XrefData const &data)
                     {
                         return data.isDefined(symbol);
                     }
                 );
 
-    if (iter != d_xrefData.end())
+    if (iter != d_xrefVector.end())
         return;                         // symbol already defined
 
     iter = find_if(
-                d_xrefData.begin(), d_xrefData.end(),
+                d_xrefVector.begin(), d_xrefVector.end(),
                 [&](XrefData const &xrefData)
                 {
                     return xrefData.hasSymbol(symbol);
@@ -23,10 +23,10 @@ void Store::define(std::string const &symbol, bool isFunction)
 
     size_t currentIdx;
 
-    if (iter != d_xrefData.end())
+    if (iter != d_xrefVector.end())
     {
-        currentIdx = iter - d_xrefData.begin();
-        d_xrefData[currentIdx].setLocation(d_sourceFile, d_objFile);
+        currentIdx = iter - d_xrefVector.begin();
+        d_xrefVector[currentIdx].setLocation(d_sourceFile, d_objFile);
         d_defIdx.push_back(currentIdx);
     }
     else
@@ -36,9 +36,9 @@ void Store::define(std::string const &symbol, bool isFunction)
                             // any *UND* elements are for function currentIdx
                             // if not a function, then d_currentIdx isn't 
                             // used with *UND* elements
-        d_defIdx.push_back(currentIdx = d_xrefData.size());
+        d_defIdx.push_back(currentIdx = d_xrefVector.size());
 
-        d_xrefData.push_back(
+        d_xrefVector.push_back(
                 XrefData(d_sourceFile, d_objFile, isFunction, symbol)
         );
     }
@@ -46,3 +46,5 @@ void Store::define(std::string const &symbol, bool isFunction)
     if (isFunction)
         d_currentIdx = currentIdx;
 }
+
+
